@@ -36,16 +36,15 @@ import pyxcp.types as types
 
 
 class Usb(BaseTransport):
-    """
-    """
+    """"""
 
     PARAMETER_MAP = {
         #                            Type    Req'd   Default
-        "serial_number":             (str,    True,  ""),
-        "configuration_number":      (int,    True,  1),
-        "interface_number":          (int,    True,  2),
-        "command_endpoint_number":   (int,    True,  0),
-        "reply_endpoint_number":     (int,    True,  1),
+        "serial_number": (str, True, ""),
+        "configuration_number": (int, True, 1),
+        "interface_number": (int, True, 2),
+        "command_endpoint_number": (int, True, 0),
+        "reply_endpoint_number": (int, True, 1),
     }
     HEADER = struct.Struct("<2H")
     HEADER_SIZE = HEADER.size
@@ -65,11 +64,11 @@ class Usb(BaseTransport):
     def connect(self):
         for device in usb.core.find(find_all=True):
             try:
-                if device.serial_number.strip().strip('\0').lower() == self.serial_number.lower():
+                if device.serial_number.strip().strip("\0").lower() == self.serial_number.lower():
                     self.device = device
                     break
                 else:
-                    print(device.serial_number.strip().strip('\0').lower(), self.serial_number.lower())
+                    print(device.serial_number.strip().strip("\0").lower(), self.serial_number.lower())
             except:
                 continue
         else:
@@ -90,12 +89,16 @@ class Usb(BaseTransport):
         HEADER_UNPACK = self.HEADER.unpack
         HEADER_SIZE = self.HEADER_SIZE
 
+        high_resolution_time = self.perf_counter_origin > 0
+        timestamp_origin = self.timestamp_origin
+        perf_counter_origin = self.perf_counter_origin
+
         processResponse = self.processResponse
         close_event_set = self.closeEvent.isSet
 
         read = self.reply_endpoint.read
 
-        header = array('B', bytes(HEADER_SIZE))
+        header = array("B", bytes(HEADER_SIZE))
 
         while 1:
 
@@ -104,7 +107,10 @@ class Usb(BaseTransport):
                     break
 
                 try:
-                    recv_timestamp = time()
+                    if high_resolution_time:
+                        recv_timestamp = time()
+                    else:
+                        recv_timestamp = timestamp_origin + perf_counter() - perf_counter_origin
                     read(header, 1)
                 except:
                     sleep(0.001)
@@ -117,14 +123,21 @@ class Usb(BaseTransport):
                 processResponse(response, length, counter, recv_timestamp)
 
             except:
-                print('recv loop error', format_exc())
+                print("recv loop error", format_exc())
                 self.status = 0  # disconnected
                 break
 
     def send(self, frame):
-        self.pre_send_timestamp = time()
-        self.command_endpoint.write(frame)
-        self.post_send_timestamp = time()
+        if self.perf_counter_origin > 0:
+            self.pre_send_timestamp = time()
+            self.command_endpoint.write(frame)
+            self.post_send_timestamp = time()
+        else:
+            pre_send_timestamp = perf_counter()
+            self.command_endpoint.write(frame)
+            post_send_timestamp = perf_counter()
+            self.pre_send_timestamp = self.timestamp_origin + pre_send_timestamp - self.perf_counter_origin
+            self.post_send_timestamp = self.timestamp_origin + post_send_timestamp - self.perf_counter_origin
 
     def closeConnection(self):
         if self.device is not None:
